@@ -1,26 +1,26 @@
 from pyalign.tests import TestCase
+from typing import Iterator
 
-import pyalign.problem
+import pyalign.problems
 import pyalign.solve
 import pyalign.gaps
 
 
 class TestBatch(TestCase):
 	def test_simd(self):
-		pf = pyalign.problem.ProblemFactory(
-			pyalign.problem.Binary(eq=1, ne=-1),
+		pf = pyalign.problems.general(
+			pyalign.problems.Equality(eq=1, ne=-1),
 			direction="maximize")
 
 		solver = pyalign.solve.GlobalSolver(
 			gap_cost=pyalign.gaps.LinearGapCost(2),
-			direction="maximize",
-			generate="alignment[all, optimal]")
+			codomain=Iterator[pyalign.solve.Alignment])
 
-		alignments = solver.solve(pyalign.solve.ProblemBatch([
+		alignments = solver.solve([
 			pf.new_problem("AATCG", "AACG"),
 			pf.new_problem("AATGC", "AACG"),
 			pf.new_problem("AATCG", "AGTT")
-		]))
+		])
 
 		self._check_alignments(
 			alignments[0],
