@@ -1,6 +1,7 @@
 from pyalign.tests import TestCase
+from typing import Iterator
 
-import pyalign.problem
+import pyalign.problems
 import pyalign.solve
 import pyalign.gaps
 
@@ -10,15 +11,14 @@ class TestWatermanSmithBeyer(TestCase):
 		# test case is taken from default settings (for logarithmic gap settings) at
 		# http://rna.informatik.uni-freiburg.de/Teaching/index.jsp?toolName=Waterman-Smith-Beyer
 
-		pf = pyalign.problem.ProblemFactory(
-			pyalign.problem.Binary(eq=1, ne=-1),
+		pf = pyalign.problems.general(
+			pyalign.problems.Equality(eq=1, ne=-1),
 			direction="maximize")
 		problem = pf.new_problem("CG", "CCGA")
 
 		solver = pyalign.solve.GlobalSolver(
 			gap_cost=pyalign.gaps.LogarithmicGapCost(3, 1),
-			direction="maximize",
-			generate="alignment[all, optimal]")
+			codomain=Iterator[pyalign.solve.Alignment])
 
 		alignments = list(solver.solve(problem))
 
